{% extends 'account/profile/base.html' %} {% load thumbnail %} {% block content %}

## Мої замовлення

{% if order_items %}

# | Дата | К-сть товарів | Сума | Статус | Звіт
--- | --- | --- | --- | --- | ---
{% for item in order_items %}
{{ item.id }} | {{ item.date_created }} | {{ item.product_count }} | {{ item.printable_total }} | {{ item.get_status_display }} | Завантажити звіт
{% endfor %}

{% else %}
У Вас поки немає замовлень
{% endif %}
{% endblock %}